You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mxnet.apache.org by GitBox <gi...@apache.org> on 2019/09/19 22:20:23 UTC

[GitHub] [incubator-mxnet] drivanov opened a new pull request #16218: Improving performance of argmax operator

drivanov opened a new pull request #16218: Improving performance of argmax operator
URL: https://github.com/apache/incubator-mxnet/pull/16218
 
 
   ## Description ##
   In average, this implementation of `argmax` operator runs 4.2x faster on CPU and 7.8x faster on GPU, than the previous one.
   
   ## Checklist ##
   ### Essentials ###
   - [x] Changes are complete (i.e. I finished coding on this PR)
   - [x] All changes have test coverage:
   - Unit tests are added for small changes to verify correctness (e.g. adding a new operator)
   - Nightly tests are added for complicated/long-running ones (e.g. changing distributed kvstore)
   - [x ] Code is well-documented: 
   - [x] To the my best knowledge, examples are either not affected by this change, or have been fixed to be compatible with this change
   
   ### Changes ###
   - [x] Two new kernels are implemented. 
   
   ## Comments ##
   - The performance of new argmax was tested on 69 different pairs `(shape, axis)` of 2- and 3-dimensional shapes. Following table contains some performance results for run time improvement:
   ```
                   CPU:       GPU:        
   Average:       4.163x     7.753x
   Maximal:      15.287x   100.157x 
   ```
   Significant improvement achieved mostly by using multiple threads working on the same vector.

----------------------------------------------------------------
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
users@infra.apache.org


With regards,
Apache Git Services